record.DomRecord

|  | ## Cheshire3 Object Model: Class DomRecord

Module record :: Class DomRecord

## Class DomRecord
source code

Object Tree:

    baseObjects.Record --+
                         |
                        DomRecord

Known Subclasses:
  FtDomRecord, LxmlRecord, MinidomRecord

Instance Methods

__init__(self, domNode, xml="", docid=None)
_walk(self, node)
get_sax(self) Return the list of SAX events for the record, serialised according to the internal C3 format.
get_dom(self) Return the DOM document node for the record.
Inherited from `baseObjects.Record`: `get_xml`, `process_xpath`

Class Variables

context |
size |
Inherited from `baseObjects.Record`: `baseUri`, `dom`, `elementHash`, `history`, `parent`, `processHistory`, `recordStore`, `resultSetItem`, `rights`, `sax`, `schema`, `schemaType`, `status`, `xml`

Method Details

### __init__(self, domNode, xml="", docid=None) (Constructor) | source code
Overrides: baseObjects.Record.__init__

### _walk(self, node) | source code

### get_sax(self) | source code
Return the list of SAX events for the record, serialised according to the internal C3 format. Overrides: baseObjects.Record.get_sax (inherited documentation)

### get_dom(self) | source code
Return the DOM document node for the record. Overrides: baseObjects.Record.get_dom (inherited documentation)

Class Variable Details

    ### context Value:
        None

    ### size Value:
        0